CodeQL / Analyze (actions) (push) Canceled after 0s
CodeQL / Analyze (python) (push) Canceled after 0s
pre-commit / pre-commit (push) Canceled after 0s
Multi-Arch CI / setup (push) Canceled after 0s
Publish build_manylinux_x86_64 images / publish_build_manylinux_x86_64 (push) Canceled after 0s
Setup (Multi-Arch) / setup (push) Canceled after 0s
Multi-Arch CI / Linux::${{ fromJSON(needs.setup.outputs.linux_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubi10 image / publish_no_rocm_image_ubi10 (push) Canceled after 0s
Multi-Arch CI / Windows::${{ fromJSON(needs.setup.outputs.windows_build_config || '{}').build_variant_label || 'skip' }} (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Multi-Arch CI / Manifest Diff (push) Canceled after 0s
TheRock Manifest Diff Report / Generate Manifest Diff Report (push) Canceled after 0s
Multi-Arch CI / CI Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_ocl_rt images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04_rocgdb images / publish_no_rocm_image_ubuntu24_04_rocgdb (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_ocl_rt (push) Canceled after 0s
Publish TheRock Docker image / build-and-push-image (push) Canceled after 0s
Unit Tests / Unit Tests :: ubuntu-24.04 (push) Canceled after 0s
Unit Tests / Unit Tests :: windows-2022 (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_media (push) Canceled after 0s
Unit Tests / Unit Tests Summary (push) Canceled after 0s
Publish no_rocm_image_ubuntu24_04 images / publish_no_rocm_image_ubuntu24_04_openmpi (push) Canceled after 0s
57 lines
1.7 KiB
C++
57 lines
1.7 KiB
C++
// RUN: %clang_cc1 -triple spirv64 -x hip -emit-llvm -fcuda-is-device \
|
|
// RUN: -o - %s | FileCheck %s
|
|
// RUN: %clang_cc1 -triple spirv64-amd-amdhsa -x hip -emit-llvm -fcuda-is-device \
|
|
// RUN: -o - %s | FileCheck %s
|
|
|
|
#define __device__ __attribute__((device))
|
|
#define __shared__ __attribute__((shared))
|
|
#define __constant__ __attribute__((constant))
|
|
|
|
// CHECK: %struct.foo_t = type { i32, ptr addrspace(4) }
|
|
|
|
// CHECK: @d ={{.*}} addrspace(1) externally_initialized global
|
|
__device__ int d;
|
|
|
|
// CHECK: @c ={{.*}} addrspace(1) externally_initialized constant
|
|
__constant__ int c;
|
|
|
|
// CHECK: @s ={{.*}} addrspace(3) global
|
|
__shared__ int s;
|
|
|
|
// CHECK: @foo ={{.*}} addrspace(1) externally_initialized global %struct.foo_t
|
|
__device__ struct foo_t {
|
|
int i;
|
|
int* pi;
|
|
} foo;
|
|
|
|
// Check literals are placed in address space 1 (CrossWorkGroup/__global).
|
|
// CHECK: @.str ={{.*}} unnamed_addr addrspace(1) constant
|
|
|
|
// CHECK: define{{.*}} spir_func noundef ptr addrspace(4) @_Z3barPi(ptr addrspace(4)
|
|
__device__ int* bar(int *x) {
|
|
return x;
|
|
}
|
|
|
|
// CHECK: define{{.*}} spir_func noundef ptr addrspace(4) @_Z5baz_dv()
|
|
__device__ int* baz_d() {
|
|
// CHECK: ret ptr addrspace(4) addrspacecast (ptr addrspace(1) @d to ptr addrspace(4)
|
|
return &d;
|
|
}
|
|
|
|
// CHECK: define{{.*}} spir_func noundef ptr addrspace(4) @_Z5baz_cv()
|
|
__device__ int* baz_c() {
|
|
// CHECK: ret ptr addrspace(4) addrspacecast (ptr addrspace(1) @c to ptr addrspace(4)
|
|
return &c;
|
|
}
|
|
|
|
// CHECK: define{{.*}} spir_func noundef ptr addrspace(4) @_Z5baz_sv()
|
|
__device__ int* baz_s() {
|
|
// CHECK: ret ptr addrspace(4) addrspacecast (ptr addrspace(3) @s to ptr addrspace(4)
|
|
return &s;
|
|
}
|
|
|
|
// CHECK: define{{.*}} spir_func noundef ptr addrspace(4) @_Z3quzv()
|
|
__device__ const char* quz() {
|
|
return "abc";
|
|
}
|